@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from lib2to3.fixer_base import BaseFix
 from lib2to3.fixer_util import find_indentation
 from lib2to3.pgen2 import token
@@ -6,7 +7,7 @@ from lib2to3.pytree import Node, Leaf
 
 
 class FixCompoundStatements(BaseFix):
-    u'''
+    '''
     Compound statements (multiple statements on the same line) are
     generally discouraged.
 
@@ -27,7 +28,7 @@ class FixCompoundStatements(BaseFix):
                 pass
             else:
                 results["colon"] = True
-        if (node.type == symbols.simple_stmt and Leaf(token.SEMI, u';') in node
+        if (node.type == symbols.simple_stmt and Leaf(token.SEMI, ';') in node
             .children):
             results["semi"] = True
         return results
@@ -43,9 +44,9 @@ class FixCompoundStatements(BaseFix):
         # Strip any whitespace that could have been there
         node_copy.prefix = node_copy.prefix.lstrip()
         old_depth = find_indentation(node)
-        new_indent = u'%s%s' % ((u' ' * 4), old_depth)
-        new_node = Node(symbols.suite, [Leaf(token.NEWLINE, u'\n'), Leaf(token
-            .INDENT, new_indent), node_copy, Leaf(token.DEDENT, u'')])
+        new_indent = '%s%s' % ((' ' * 4), old_depth)
+        new_node = Node(symbols.suite, [Leaf(token.NEWLINE, '\n'), Leaf(token
+            .INDENT, new_indent), node_copy, Leaf(token.DEDENT, '')])
         node.replace(new_node)
         node.changed()
 
@@ -64,7 +65,7 @@ class FixCompoundStatements(BaseFix):
                 # Replace the semi with a newline
                 old_depth = find_indentation(child)
 
-                child.replace([Leaf(token.NEWLINE, u'\n'), Leaf(token.INDENT,
+                child.replace([Leaf(token.NEWLINE, '\n'), Leaf(token.INDENT,
                     old_depth)])
                 child.changed()
         return node
